"use client";

import { getFetch } from "@/lib/doFetch";
import { useRequest } from "ahooks";
import { Image, Divider, Button } from "@nextui-org/react";
import dayjs from "dayjs";
import { BsFolderFill } from "react-icons/bs";
import EditFolder from "@/components/EditFolder";
import DeleteFolder from "@/components/DeleteFolder";

export default function Detail({ folder, params }) {
  //params.slug 路由传参获取

  const { data, refreshAsync } = useRequest(
    async () => {
      let res = await getFetch({
        url: "/api/folder/" + params.slug,
        params: {},
      });
      return res?.data;
    },
    {
      refreshDeps: [params.slug],
    }
  );

  return (
    <div className="flex w-full">
      <Image
        isBlurred
        className="object-cover w-100 m-12"
        src={data?.poster}
        width={400}
        alt="avatar"
      />
      <div className="max-w-md ml-20 mt-12 flex-1">
        <div className="space-y-1">
          <h1 className="text-2xl mb-2">{data?.name}</h1>
          <p className="text-small text-default-400 ">
            创建时间:
            {data?.createdAt
              ? dayjs(data.createdAt).format("YYYY-MM-DD hh:mm:ss")
              : "-"}
          </p>
        </div>
        <Divider className="my-4" />
        <div className="flex h-5 items-center space-x-4 text-small mt-8">
          <DeleteFolder data={data} refresh={refreshAsync}></DeleteFolder>

          <Divider orientation="vertical" />
          <EditFolder data={data} refresh={refreshAsync} />
          <Divider orientation="vertical" />
          <Button
            isIconOnly
            color="primary"
            variant="faded"
            aria-label="Take a edit"
          >
            <BsFolderFill style={{ fontSize: "20px" }} />
          </Button>
        </div>
      </div>
    </div>
  );
}
